/* +--------------------------------------------------------------------------+
//  2002-2010 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: visionneuse.css,v 1.3 2012-12-12 15:40:59 trenon Exp $ */

#visionneuse #visionneuseIframe {
	-moz-border-radius : 10px;
	-webkit-border-radius : 10px;
	border-radius : 10px;
	-moz-box-shadow: 0px 0px 5px #666666;
	-webkit-box-shadow: 0px 0px 5px #666666;
	box-shadow: 0px 0px 5px #666666;
	overflow: hidden;
}

#next, #previous {
	cursor: pointer;
}

#visionneuseBackground {
	-moz-opacity: 0.5;
	opacity: 0.5;
	filter: alpha(opacity=50);
	width: 100%;
	height: 100%;
	position: absolute;
	top: 0;
	left: 0;
	z-index:9001;
	background-color: #2C2E8C;
}

.linkFullscreen {
	position: absolute;
	right: 2%;
	bottom: 1%;
}

.close {
	position: absolute;
	right: 2%;
	top: 0%;
}

#visio_navigator {
	height: 40px;
	width: 100%;
	margin-top: 0.8em;
}

#visio_current_description {
	text-align: left;
	margin-top: 3em;	
}

#visio_current_object {
	padding: 1em;
	margin-top: 1.4em;
	text-align: center;
}

#wait {
	position: absolute;
	top: 200px;
	left: 50%;
	margin-left: -16px;
}
